<%! from kaithem.src import notifications,auth,unitsofmeasure,pages,alerts,theming import time from kaithem.src.config import config from kaithem.src.unitsofmeasure import format_time_interval pcolor={ "critical": "pink", "error": 'red', "warning": 'orange', "info": 'lightgreen' } iclass={ "critical": "critical-icon", "error": 'error-icon', "warning": 'warning-icon', "info": 'info-icon' } scolor={ 'active':'yellow', 'acknowledged':'orange', "cleared":'blue' } %>
{{formatTime(i[0])}}

{{i[2]}}